summaryrefslogtreecommitdiffstats
path: root/kio/kfile/kcustommenueditor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kfile/kcustommenueditor.cpp')
-rw-r--r--kio/kfile/kcustommenueditor.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kio/kfile/kcustommenueditor.cpp b/kio/kfile/kcustommenueditor.cpp
index 3b4e9a68c..aec3c10f1 100644
--- a/kio/kfile/kcustommenueditor.cpp
+++ b/kio/kfile/kcustommenueditor.cpp
@@ -57,8 +57,8 @@ public:
TQString serviceName = s->name();
// item names may contain ampersands. To avoid them being converted
- // to accelators, tqreplace them with two ampersands.
- serviceName.tqreplace("&", "&&");
+ // to accelators, replace them with two ampersands.
+ serviceName.replace("&", "&&");
TQPixmap normal = KGlobal::instance()->iconLoader()->loadIcon(s->icon(), KIcon::Small,
0, KIcon::DefaultState, 0L, true);
@@ -99,7 +99,7 @@ KCustomMenuEditor::KCustomMenuEditor(TQWidget *parent)
d->pbRemove=buttonBox->addButton(i18n("Remove"), this, TQT_SLOT(slotRemoveItem()));
d->pbMoveUp=buttonBox->addButton(i18n("Move Up"), this, TQT_SLOT(slotMoveUp()));
d->pbMoveDown=buttonBox->addButton(i18n("Move Down"), this, TQT_SLOT(slotMoveDown()));
- buttonBox->tqlayout();
+ buttonBox->layout();
connect( m_listView, TQT_SIGNAL( selectionChanged () ), this, TQT_SLOT( refreshButton() ) );
refreshButton();
}